==> igniteui-angular-core-17.3.0.tgz: package/esm2015/lib/GeographicXYTriangulatingSeriesBaseDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { GeographicMapSeriesHostDescriptionMetadata } from "./GeographicMapSeriesHostDescriptionMetadata";
/**
 * @hidden
 */
export let GeographicXYTriangulatingSeriesBaseDescriptionMetadata = /*@__PURE__*/ (() => {
    class GeographicXYTriangulatingSeriesBaseDescriptionMetadata extends Base {
        static b(a) {
            if (GeographicXYTriangulatingSeriesBaseDescriptionMetadata.a == null) {
                GeographicXYTriangulatingSeriesBaseDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                GeographicXYTriangulatingSeriesBaseDescriptionMetadata.c(GeographicXYTriangulatingSeriesBaseDescriptionMetadata.a);
            }
            if (a.k(GeographicXYTriangulatingSeriesBaseDescriptionMetadata.a)) {
                return;
            }
            a.ab(GeographicXYTriangulatingSeriesBaseDescriptionMetadata.a);
        }
        static c(a) {
            GeographicMapSeriesHostDescriptionMetadata.c(a);
        }
        static d(a) {
            GeographicXYTriangulatingSeriesBaseDescriptionMetadata.b(a);
            a.ac("GeographicXYTriangulatingSeriesBase", GeographicXYTriangulatingSeriesBaseDescriptionMetadata.a);
        }
    }
    GeographicXYTriangulatingSeriesBaseDescriptionMetadata.$t = markType(GeographicXYTriangulatingSeriesBaseDescriptionMetadata, 'GeographicXYTriangulatingSeriesBaseDescriptionMetadata');
    GeographicXYTriangulatingSeriesBaseDescriptionMetadata.a = null;
    return GeographicXYTriangulatingSeriesBaseDescriptionMetadata;
})();

==> igniteui-angular-core-20.0.0.tgz: package/esm2015/lib/GeographicXYTriangulatingSeriesBaseDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { GeographicMapSeriesHostDescriptionMetadata } from "./GeographicMapSeriesHostDescriptionMetadata";
/**
 * @hidden
 */
export let GeographicXYTriangulatingSeriesBaseDescriptionMetadata = /*@__PURE__*/ (() => {
    class GeographicXYTriangulatingSeriesBaseDescriptionMetadata extends Base {
        static b(a) {
            if (GeographicXYTriangulatingSeriesBaseDescriptionMetadata.a == null) {
                GeographicXYTriangulatingSeriesBaseDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                GeographicXYTriangulatingSeriesBaseDescriptionMetadata.c(GeographicXYTriangulatingSeriesBaseDescriptionMetadata.a);
            }
            if (a.k(GeographicXYTriangulatingSeriesBaseDescriptionMetadata.a)) {
                return;
            }
            a.ac(GeographicXYTriangulatingSeriesBaseDescriptionMetadata.a);
        }
        static c(a) {
            GeographicMapSeriesHostDescriptionMetadata.c(a);
        }
        static d(a) {
            GeographicXYTriangulatingSeriesBaseDescriptionMetadata.b(a);
            a.ad("GeographicXYTriangulatingSeriesBase", GeographicXYTriangulatingSeriesBaseDescriptionMetadata.a);
        }
    }
    GeographicXYTriangulatingSeriesBaseDescriptionMetadata.$t = markType(GeographicXYTriangulatingSeriesBaseDescriptionMetadata, 'GeographicXYTriangulatingSeriesBaseDescriptionMetadata');
    GeographicXYTriangulatingSeriesBaseDescriptionMetadata.a = null;
    return GeographicXYTriangulatingSeriesBaseDescriptionMetadata;
})();
